Feature
=======

- manage request too long by Filter and @
- manage level by rule (change by api)
- change work of print function
- test access.log with goaccess
- add fct for debug if status >= 500 and not mode debug

V. 0.1.0
========

- init
- add request_id
- add info from config and request
- add info timestamp
